//
//  LSAlert.h
//  LightSpeed Cocoa
//
//  Created by Bertrand Landry-Hétu on 2010/05/17.
//  Copyright 2010 Xsilva Systems. All rights reserved.
//

#import <Cocoa/Cocoa.h>

extern const int LSAlertReportSent;

/*! This free function is used as an uncaught exception handler. */
void LSReportUncaughtException(NSException* exception);

typedef enum {
    LSMessageAlertStyle = 0,
    LSErrorAlertStyle = 1,
} LSAlertStyle;

@interface LSAlert : NSObject {
@private
	NSString *messageTitle;
	NSString *messageText;
	NSString *informativeText;
    NSString *title;
	NSImage *icon;
	NSMutableArray *buttons;
	LSAlertStyle style;
	NSString *errorType;
	NSError * displayedError;
	BOOL hideMoreInfo;
}

+ (id)alertWithError:(NSError *)error;

+ (id)alertWithMessageText:(NSString *)message defaultButton:(NSString *)defaultButton alternateButton:(NSString *)alternateButton 
			   otherButton:(NSString *)otherButton informativeTextWithFormat:(NSString *)format, ...;

+ (id)saveAlertWithMessageText:(NSString *)message informativeTextWithFormat:(NSString *)format;

@property(nonatomic, copy) NSString * messageTitle;
@property(nonatomic, copy) NSString * messageText;
@property(nonatomic, copy) NSString * informativeText;
@property(nonatomic, copy) NSString * title;
@property(nonatomic, retain) NSImage * icon;
@property(nonatomic, readonly) NSArray * buttons;
@property(nonatomic, assign) LSAlertStyle style;

@property(nonatomic, copy, readonly) NSString * errorType;
@property(nonatomic, retain, readonly) NSError * displayedError;
@property(nonatomic, assign, readonly) BOOL hideMoreInfo;

/*! to be overriden by subclassed to change the type of buttons used*/
-(Class)buttonClass;

/*! runs this dialog as a modal window */
-(NSInteger)runModal;

/*! runs this dialog as a sheet */
-(void)beginSheetModalForWindow:(NSWindow *)window didEndBlock: (void (^)(NSInteger returnCode))block;

/*! Appends a button to the list of button with the specified title. the returned button is a -(Class)buttonClass type. */
-(id)addButtonWithTitle:(NSString *)theTitle;

@end
