//
//  LSBProcessCreditCardWindowController.h
//  LightSpeed Cocoa
//
//  Created by Bertrand Landry-Hétu on 11-04-11.
//  Copyright 2011 Xsilva Systems. All rights reserved.
//

#import <Cocoa/Cocoa.h>
@class LSBCreditCardPaymentInfo;
@class XSACreditCardEventFilter;
@class LSBIPDebitTerminal;

typedef void(^LSBProcessCreditCardDialogCompletion)(BOOL processed) ;

typedef enum {
    LSBSaleMode = 0,
    LSBVoidMode,
    LSBRefundMode,
    LSBOfflineMode,
    LSBManualMode,
} LSBPCCMode;


@interface LSBProcessCreditCardWindowController : NSWindowController {
@private
    IBOutlet NSWindow *processingSheet;
    IBOutlet NSTextField *processingTitle;
    IBOutlet NSTextField *processingMessage;
    IBOutlet NSProgressIndicator *processingProgress;
    IBOutlet NSButton *cancelProcessingButton;

    IBOutlet NSButton *swipeModeButton;
    
    IBOutlet NSTextField *referenceIdLabel;
    IBOutlet NSTextField *referenceIdField;
    
    IBOutlet NSImageView *warningImage;
    IBOutlet NSTextField *warningLabel;
    
    IBOutlet NSButton *okButton;

    IBOutlet NSWindow *successWindow;
    IBOutlet NSTextField *successMessage;
    
    IBOutlet NSWindow *failureWindow;
    IBOutlet NSTextField *errorCodeField;
    IBOutlet NSView *errorCodeSectionView;
    IBOutlet NSButton *errorDisclosureButton;

    LSBProcessCreditCardDialogCompletion completion;
    NSDecimalNumber *requestedAmount;

    XSBaseDocument * baseDocument;
    XSPaymentMethod *method;
    XSCreditCardProcessor *processor;
    XSTill *till;
    
    LSBCreditCardPaymentInfo *paymentInfo;
    
    NSUInteger busyCount;
    BOOL swipeMode;
    
    LSBIPDebitTerminal *ipDebitTerminal;
    
    LSBPCCMode mode;
}
@property(nonatomic, assign) BOOL swipeMode;

+(LSBProcessCreditCardWindowController*)processCreditCardWindowForDocument:(XSBaseDocument*)document
                                                             paymentMethod:(XSPaymentMethod*)method
                                                                    amount:(NSDecimalNumber *)amount
                                                      usingUsingCompletion:(LSBProcessCreditCardDialogCompletion)aCompletion;

- (IBAction)cancel:(id)sender;
- (IBAction)process:(id)sender;

- (IBAction)saleMode:(id)sender;
- (IBAction)refundMode:(id)sender;
- (IBAction)voidMode:(id)sender;
- (IBAction)offlineMode:(id)sender;
- (IBAction)manualMode:(id)sender;

- (IBAction)dismissSuccessWindow:(id)sender;
- (IBAction)dismissFailureWindow:(id)sender;
- (IBAction)toggleErrorCodeSection:(id)sender;

@end
