//
//  LSUserSetupController.h
//  LightSpeed Cocoa
//
//  Created by Bertrand Landry-Hétu on 2010/10/07.
//  Copyright 2010 Xsilva Systems. All rights reserved.
//

#import <Cocoa/Cocoa.h>

@protocol XSAsynchronousOperation;
@protocol LSUserSetupControllerDelegate;

@interface LSUserSetupController : NSWindowController {
	NSTableView * tableView;
	NSTabView * tabView;
	NSSearchField * searchField;
	NSObjectController * selectedUserController;
	NSObjectController * proxyObjectController;
	NSArrayController * userArrayController;
	NSArrayController * privilegeArrayController;
	NSProgressIndicator * userListProgressIndicator;
	NSTextField * userListStatus;
	NSTextField * usernameField;
	NSTextField * reservedUsernameLabel;
	NSTextField * duplicateUsernameLabel;
	NSTextField * jobProductField;
	NSTextField * invalidProductLabel;
	
	XSConnection * connection;
	XSFBindingHelper *binder;
	id<XSAsynchronousOperation> filteredFetchOperation;
	id<XSAsynchronousOperation> privilegeFetchOperation;
	id<XSAsynchronousOperation> userInfoFetchOperation;
	id<LSUserSetupControllerDelegate> delegate;
	NSUInteger unfilteredUserCount;
	XSUser * selectedUser;
	XSUser * editedUser;
	XSResourceArray * privileges;
	BOOL busy;
	BOOL canChangeSelection;
	
	void(^previousUserListRequestCompletion)(BOOL success);
}
@property(nonatomic, retain) IBOutlet NSTableView * tableView;
@property(nonatomic, retain) IBOutlet NSTabView * tabView;
@property(nonatomic, retain) IBOutlet NSSearchField * searchField;
@property(nonatomic, retain) IBOutlet NSObjectController * selectedUserController;
@property(nonatomic, retain) IBOutlet NSObjectController * proxyObjectController;
@property(nonatomic, retain) IBOutlet NSArrayController * userArrayController;
@property(nonatomic, retain) IBOutlet NSArrayController * privilegeArrayController;
@property(nonatomic, retain) IBOutlet NSProgressIndicator * userListProgressIndicator;
@property(nonatomic, retain) IBOutlet NSTextField * userListStatus;
@property(nonatomic, retain) IBOutlet NSTextField * usernameField;
@property(nonatomic, retain) IBOutlet NSTextField * reservedUsernameLabel;
@property(nonatomic, retain) IBOutlet NSTextField * duplicateUsernameLabel;
@property(nonatomic, retain) IBOutlet NSTextField * jobProductField;
@property(nonatomic, retain) IBOutlet NSTextField * invalidProductLabel;
@property(nonatomic, assign) id<LSUserSetupControllerDelegate> delegate;
@property(nonatomic, assign, readonly) BOOL userListIsLoading;
@property(nonatomic, assign) BOOL busy;
@property(nonatomic, assign) BOOL canChangeSelection;

-(id)initWithConnection:(XSConnection *)connection;

-(IBAction)userFilterChanged:(id)sender;

-(IBAction)createUser:(id)sender;
-(IBAction)delete:(id)sender;
-(IBAction)changePassword:(id)sender;
-(IBAction)revert:(id)sender;
-(IBAction)save:(id)sender;
-(IBAction)unlockUser:(id)sender;
-(IBAction)reactivateUser:(id)sender;
-(IBAction)toggledUserEnabled:(id)sender;

@end

@protocol LSUserSetupControllerDelegate
- (void)windowClosed:(LSUserSetupController *)controller;
@end
